@@ -66,20 +66,7 @@ class GUI_Crypt_me(QtGui.QWidget):
         label_2 = QtGui.QLabel("Paraphrase: (should be a number)",self)
         label_3 = QtGui.QLabel("Output text:",self)
         label_4 = QtGui.QLabel("bo_92 2014          martin.bednar@hotmail.sk",self)
-
-        '''menu_bar = QtGui.QMenuBar(self)
-        menu = QtGui.QMenu(self)
-        action = QtGui.QAction(self)'''
-        global a
         vbox = QtGui.QVBoxLayout()
-        a = vbox
-        #vbox.addWidget(lcd)
-        #vbox.addWidget(sld)
-        '''vbox.addWidget(menu_bar)
-        vbox.addWidget(menu)
-        vbox.addWidget(action)'''
-
-
         vbox.addWidget(label_0)
         vbox.addWidget(label_1)
         vbox.addWidget(self.text_in)
@@ -93,10 +80,7 @@ class GUI_Crypt_me(QtGui.QWidget):
         vbox.addWidget(label_4)
         crypt_button.clicked[bool].connect(self.set_output_text_crypt)
         decrypt_button.clicked[bool].connect(self.set_output_text_decrypt)
-
         self.setLayout(vbox)
-        #sld.valueChanged.connect(lcd.display)
-        
         self.setGeometry(300, 300, 500, 150)
         self.setWindowTitle('Crypt_me!')
         self.show()
@@ -122,9 +106,6 @@ class GUI_Crypt_me(QtGui.QWidget):
                 global warning_2
                 self.text_out.append(warning_2)
 
-
-            
-
     def set_output_text_decrypt(self, pressed):
         source = self.sender()
         if(pressed):
